@@ -2,7 +2,7 @@ from sys import stderr
 from fusil.mas.message import Message
 from fusil.mas.mailbox import Mailbox
 from weakref import ref as weakref_ref
-from fusil.error import FUSIL_ERRORS, writeError
+from ptrace.error import PTRACE_ERRORS, writeError
 from fusil.mas.agent_id import AgentID
 
 class AgentError(Exception):
@@ -16,6 +16,10 @@ class Agent(object):
         self.setupMTA(mta)
 
     def setupMTA(self, mta, logger=None):
+        """
+        Create the mailbox and store a weak reference the message transfert
+        agent (MTA).
+        """
         if mta:
             if logger:
                 self.logger = logger
@@ -33,21 +37,27 @@ class Agent(object):
 
     def __del__(self):
         try:
-            self.debug("Destroy")
-            self.deactivate()
+            if hasattr(self, 'is_active'):
+                self.deactivate()
             if hasattr(self, "mailbox") and self.mailbox:
                 self.mailbox.unregister()
             self.destroy()
         except KeyboardInterrupt:
             self.error("Agent destruction interrupted!")
             self.send('application_interrupt')
-        except FUSIL_ERRORS, error:
+        except PTRACE_ERRORS, error:
             writeError(self, error, "Agent destruction error")
 
     def destroy(self):
+        """
+        (Abstract method) Method called on agent destruction: cleanup data.
+        """
         pass
 
     def getEvents(self):
+        """
+        List events which the agent listen on
+        """
         events = set()
         for attrname in dir(self):
             if attrname.startswith("on_"):
@@ -55,10 +65,12 @@ class Agent(object):
         return events
 
     def send(self, event, *arguments):
+        """
+        send(event, *arguments): send a message (event) to other agents
+        """
         if not self.is_active:
             raise AgentError("Inactive agent are not allowed to send message!")
         message = Message(event, arguments)
-        self.info("Send %r" % message)
         mta = self.mta()
         if mta is not None:
             mta.deliver(message)
@@ -66,6 +78,10 @@ class Agent(object):
             self.error("Unable to send %r: MTA is missing" % message)
 
     def readMailbox(self):
+        """
+        Read the mailbox: "execute" each message.
+        Return the number of executed messages.
+        """
         count = 0
         while self.mailbox:
             message = self.mailbox.pop()
@@ -74,27 +90,40 @@ class Agent(object):
         return count
 
     def activate(self):
+        """
+        Enable an agent: call init() method if the agent was disabled.
+        """
         if self.is_active:
             raise AgentError("%r is already activated!" % self)
-        self.debug("Activate")
         self.mailbox.clear()
         self.is_active = True
         self.init()
 
     def deactivate(self):
-        if not hasattr(self, 'is_active') or not self.is_active:
+        """
+        Disable an agent: call deinit() method if the agent was enabled.
+        """
+        if not self.is_active:
             return
-        self.debug("Deactivate")
         self.is_active = False
         self.deinit()
 
     def init(self):
+        """
+        Abstract method called by activate()
+        """
         pass
 
     def live(self):
+        """
+        Abstract method called at each univers step.
+        """
         pass
 
     def deinit(self):
+        """
+        Abstract method called by deactivate()
+        """
         pass
 
     def _log(self, level, message):
@@ -107,15 +136,27 @@ class Agent(object):
         func(message, sender=self)
 
     def debug(self, message):
+        """
+        Write a message to the log with DEBUG level
+        """
         self._log('debug', message)
 
     def info(self, message):
+        """
+        Write a message to the log with INFO level
+        """
         self._log('info', message)
 
     def warning(self, message):
+        """
+        Write a message to the log with WARNING level
+        """
         self._log('warning', message)
 
     def error(self, message):
+        """
+        Write a message to the log with ERROR level
+        """
         self._log('error', message)
 
     def __repr__(self):
@@ -124,5 +165,5 @@ class Agent(object):
             self.name, self.is_active)
 
     def __str__(self):
-        return repr(self)
+        return '<%s %r>' % (self.__class__.__name__, self.name)
 
