@@ -4,9 +4,9 @@ Classes mockup used for unit tests.
 
 from weakref import ref
 
-class NullLogger:
-    def __init__(self):
-        self.show = False
+class Logger:
+    def __init__(self, show=False):
+        self.show = show
 
     def debug(self, message, sender=None):
         self.display(message)
@@ -28,7 +28,7 @@ class NullLogger:
 class MTA:
     def __init__(self, logger=None):
         if not logger:
-            logger = NullLogger()
+            logger = Logger()
         self.logger = logger
 
     def registerMailingList(self, mailbox, event):
@@ -42,12 +42,25 @@ class Application:
     def __init__(self):
         self.options = Options()
 
+    def initX11(self):
+        pass
+
+class Config:
+    def __getattr__(self, name):
+        return None
+
+class Debugger:
+    def tracePID(self, agent, pid):
+        pass
+
 class Project:
     def __init__(self, logger=None):
         self._mta = MTA(logger)
         self.mta = ref(self._mta)
         self._application = Application()
         self.application = ref(self._application)
+        self.debugger = Debugger()
+        self.config = Config()
 
     def registerAgent(self, agent):
         pass
