@@ -1,13 +1,16 @@
 from fusil.project_agent import ProjectAgent
-from socket import socket, error as socket_error
-from fusil.error import formatError, writeError
+from socket import (socket, SHUT_RDWR,
+    error as socket_error,
+    timeout as socket_timeout)
+from ptrace.error import formatError, writeError
 from fusil.network.tools import formatAddress
 from time import time
+from errno import EAGAIN
 
 class NetworkClient(ProjectAgent):
     def __init__(self, project, name):
         ProjectAgent.__init__(self, project, name)
-        self.log_data_exchange = True
+        self.log_data_exchange = False
 
     def init(self):
         self.socket = None
@@ -39,23 +42,32 @@ class NetworkClient(ProjectAgent):
         if info:
             self.warning(", ".join(info))
 
+    def on_session_stop(self):
+        self.closeSocket()
+
+    def closeSocket(self):
+        if self.socket:
+            self.socket.shutdown(SHUT_RDWR)
+            self.socket.close()
+        self.socket = None
+
     def sendBytes(self, data, timeout=0):
         if self.socket is None:
             self.error("Error: socket is not initialized!")
             return False
         self.tx_bytes += len(data)
         if self.log_data_exchange:
-            self.info("Send bytes: (%s) %r (timeout=%s)" % (
+            self.warning("Send bytes: (%s) %r (timeout=%s)" % (
                 len(data), data, timeout))
         try:
             self.socket.settimeout(timeout)
             self.socket.send(data)
-            return True
         except socket_error, err:
             self.warning("Send error: %s" % formatError(err))
-            self.socket = None
+            self.closeSocket()
             self.send('session_stop')
-        return False
+            return False
+        return True
 
     def recvBytes(self, max_size=None, timeout=0.250, buffer_size=1024):
         if self.socket is None:
@@ -66,22 +78,32 @@ class NetworkClient(ProjectAgent):
         data_len = 0
         time_end = time() + timeout
         while True:
-            time_diff = time_end - time()
-            if time_diff < 0:
-                break
+            if (not datas) and (not timeout):
+                # First step in non blocking mode
+                time_diff = 0
+            else:
+                time_diff = time_end - time()
+                if time_diff < 0:
+                    break
             if max_size is not None and max_size <= data_len:
                 break
             try:
                 self.socket.settimeout(time_diff)
                 data = self.socket.recv(buffer_size)
+            except socket_timeout:
+                break
             except socket_error, err:
+                code = err.args[0]
+                if not time_diff and code == EAGAIN:
+                    break
                 self.warning("Receive error: %s" % formatError(err))
-                self.socket = None
+                self.closeSocket()
                 self.send('session_stop')
                 break
             if not data:
                 break
-            self.info("Receive bytes: (%s) %r" % (len(data), data))
+            if self.log_data_exchange:
+                self.warning("Receive bytes: (%s) %r" % (len(data), data))
             datas.append(data)
             data_len += len(data)
             self.rx_bytes += data_len
