@@ -1,5 +1,17 @@
 from itertools import izip
-from ptrace.tools import minmax
+
+def minmax(min_value, value, max_value):
+    """
+    Restrict value to [min_value; max_value]
+
+    >>> minmax(-2, -3, 10)
+    -2
+    >>> minmax(-2, 27, 10)
+    10
+    >>> minmax(-2, 0, 10)
+    0
+    """
+    return min(max(min_value, value), max_value)
 
 def listDiff(old, new):
     """
@@ -24,3 +36,12 @@ def timedeltaSeconds(delta):
     return delta.microseconds / 1000000.0 + delta.seconds \
         + delta.days * 3600 * 24
 
+def makeUnicode(text):
+    if isinstance(text, unicode):
+        return text
+    try:
+        return unicode(text, "utf8")
+    except UnicodeError:
+        pass
+    return unicode(text, "ISO-8859-1")
+
