@@ -30,18 +30,23 @@ def main():
     fusil_dir = dirname(__file__)
     sys_path.append(fusil_dir)
 
+
     # Test documentation in doc/*.rst files
     testDoc('doc/c_tools.rst')
     testDoc('doc/file_watch.rst')
     testDoc('doc/mangle.rst')
+    testDoc('doc/process.rst')
 
     # Unit tests as reST
     testDoc('tests/file_watch_read.rst')
+    testDoc('tests/file_watch_ignore.rst')
     testDoc('tests/cmd_help_parser.rst')
 
     # Test documentation of some functions/classes
+    testModule("fusil.bits")
     testModule("fusil.tools")
-    testModule("fusil.fuzzer.python")
+    testModule("fusil.process.replay_python")
+    testModule("fusil.process.tools")
 
 if __name__ == "__main__":
     main()
